import datetime

import logging
import os
import tempfile

log = logging.getLogger(__name__)


class Config(object):
    SECRET_KEY = os.environ.get('SECRET_KEY') or 'you-will-never-guess'
    JWT_SECRET_KEY = os.environ.get('JWT_SECRET_KEY') or 'super-safe'
    JWT_REFRESH_TOKEN_EXPIRES = datetime.timedelta(days=30)
    JWT_ACCESS_TOKEN_EXPIRES = datetime.timedelta(hours=1)
    LOGGER_NAME = "flask"
    API_PREFIX = os.environ.get('PORTAL_API_PREFIX', default="/api/v1.0/")


class DevelopmentConfig(Config):
    SQLALCHEMY_DATABASE_URI = 'sqlite://'
    SQLALCHEMY_TRACK_MODIFICATIONS = True
    PORTAL_ENV = 'dev'
    PORTAL_ADMIN_USER_PASSWORD = '789789'
    DEBUG = True


class ProductionConfig(Config):
    DEBUG = False


class TestConfig(Config):
    SQLALCHEMY_TRACK_MODIFICATIONS = False
    TESTING = True
    # SQLALCHEMY_ECHO = True
    PORTAL_ENV = 'dev'
    PORTAL_STORAGE_BASE_DIR = tempfile.mkdtemp()
    PORTAL_STORAGE_TEST_FILES_DIR = f"{PORTAL_STORAGE_BASE_DIR}/test-files"
    PORTAL_STORAGE_WORKSPACE_DIR = f"{PORTAL_STORAGE_BASE_DIR}/workspace"
    PORTAL_STORAGE_SUBMISSIONS_DIR = f"{PORTAL_STORAGE_BASE_DIR}/submissions"
    PORTAL_ADMIN_USER_USERNAME = 'admin'
    PORTAL_ADMIN_USER_PASSWORD = '789789'
    EMAIL_BACKEND = 'flask_emails.backends.DummyBackend'


CONFIGURATIONS = dict(
    dev=DevelopmentConfig(),
    test=TestConfig(),
    production=ProductionConfig()
    )
